@@ -12,7 +12,7 @@ ThreepSeriesModel14<-structure(
    a21,  ##<< A scalar with the value of the transfer rate from pool 1 to pool 2.
    a32,  ##<< A scalar with the value of the transfer rate from pool 2 to pool 3 as Delta14C values in per mil.
    xi=1,   ##<< A scalar or a data.frame specifying the external (environmental and/or edaphic) effects on decomposition rates. 
-   FcAtm,##<< A Data Frame object containing values of atmospheric Delta14C per time. First column must be time values, second column must be Delta14C values in per mil.
+   inputFc,##<< A Data Frame object containing values of atmospheric Delta14C per time. First column must be time values, second column must be Delta14C values in per mil.
    lambda=-0.0001209681, ##<< Radioactive decay constant. By default lambda=-0.0001209681 y^-1 . This has the side effect that all your time related data are treated as if the time unit was year.
    lag=0, ##<< A positive scalar representing a time lag for radiocarbon to enter the system. 
    solver=deSolve.lsoda.wrapper, ##<< A function that solves the system of ODEs. This can be \code{\link{euler}} or \code{\link{ode}} or any other user provided function with the same interface.
@@ -24,19 +24,19 @@ ThreepSeriesModel14<-structure(
     if(length(ks)!=3) stop("ks must be of length = 3")
     if(length(C0)!=3) stop("the vector with initial conditions must be of length = 3")
     
-    if(length(In)==1) inputFluxes=new("TimeMap",
+    if(length(In)==1) inputFluxes=BoundInFlux(
+                                      function(t){matrix(nrow=3,ncol=1,c(In,0,0))},
                                       t_start,
-                                      t_stop,
-                                      function(t){matrix(nrow=3,ncol=1,c(In,0,0))}
+                                      t_stop
                                       )
     if(class(In)=="data.frame"){
       x=In[,1]  
       y=In[,2]  
       inputFlux=function(t0){as.numeric(spline(x,y,xout=t0)[2])}
-      inputFluxes=new("TimeMap",
+      inputFluxes=BoundInFlux(
+                      function(t){matrix(nrow=3,ncol=1,c(inputFlux(t),0,0))},
                       t_start,
-                      t_stop,
-                      function(t){matrix(nrow=3,ncol=1,c(inputFlux(t),0,0))}
+                      t_stop
                       )   
     }
     
@@ -53,17 +53,17 @@ ThreepSeriesModel14<-structure(
     A[2,1]=a21
     A[3,2]=a32
     
-    At=new(Class="DecompositionOperator",
-           t_start,
-           t_stop,
+    At=BoundLinDecompOp(
            function(t){
              fX(t)*A
-           }
+           },
+           t_start,
+           t_stop
            ) 
     
-    Fc=FcAtm.from.Dataframe(FcAtm,lag,format="Delta14C")
+    Fc=BoundFc(inputFc,lag=lag,format="Delta14C")
     
-    mod=GeneralModel_14(t,At,ivList=C0,initialValF=SoilR.F0.new(F0_Delta14C,"Delta14C"),inputFluxes=inputFluxes,Fc,di=lambda,pass=pass)
+    mod=GeneralModel_14(t,At,ivList=C0,initialValF=ConstFc(F0_Delta14C,"Delta14C"),inputFluxes=inputFluxes,Fc,di=lambda,pass=pass)
     ### A Model Object that can be further queried 
     ##seealso<< \code{\link{ThreepParallelModel14}}, \code{\link{ThreepFeedbackModel14}} 
   }
@@ -76,7 +76,7 @@ ThreepSeriesModel14<-structure(
     Ex=ThreepSeriesModel14(
       t=years,ks=c(k1=1/2.8, k2=1/35, k3=1/100),
       C0=c(200,5000,500), F0_Delta14C=c(0,0,0),
-      In=LitterInput, a21=0.1, a32=0.01,FcAtm=C14Atm_NH
+      In=LitterInput, a21=0.1, a32=0.01,inputFc=C14Atm_NH
     )
     R14m=getF14R(Ex)
     C14m=getF14C(Ex)
