@@ -3,6 +3,7 @@
 TwopFeedbackModel<-structure(
     function #Implementation of a two pool model with feedback structure
     ### This function creates a model for two pools connected with feedback. It is a wrapper for the more general function \code{\link{GeneralModel}}.
+    ##references<< Sierra, C.A., M. Mueller, S.E. Trumbore. 2012. Models of soil organic matter decomposition: the SoilR package version 1.0. Geoscientific Model Development 5, 1045-1060.
      (t,    	##<< A vector containing the points in time where the solution is sought.
       ks,	##<< A vector of length 2 with the values of the decomposition rate for pools 1 and 2. 
       a21, ##<< A scalar with the value of the transfer rate from pool 1 to pool 2.
@@ -20,20 +21,20 @@ TwopFeedbackModel<-structure(
       if(length(C0)!=2) stop("the vector with initial conditions must be of length = 2")
       
       if(length(In)==1){
-          inputFluxes=TimeMap.new(
+          inputFluxes=BoundInFlux(
+            function(t){matrix(nrow=2,ncol=1,c(In,0))},
             t_start,
-            t_end,
-            function(t){matrix(nrow=2,ncol=1,c(In,0))}
+            t_end
           )
       }
       if(class(In)=="data.frame"){
          x=In[,1]  
          y=In[,2]  
          inputFlux=splinefun(x,y)
-         inputFluxes=TimeMap.new(
+         inputFluxes=BoundInFlux(
+            function(t){matrix(nrow=2,ncol=1,c(inputFlux(t),0))},
             min(x),
-            max(x),
-            function(t){matrix(nrow=2,ncol=1,c(inputFlux(t),0))}
+            max(x)
          )
         }
       A=-1*abs(diag(ks))
@@ -46,10 +47,10 @@ TwopFeedbackModel<-structure(
         Y=xi[,2]
         fX=function(t){as.numeric(spline(X,Y,xout=t)[2])}
        }
-      Af=TimeMap.new(
+      Af=BoundLinDecompOp(
+        function(t){fX(t)*A},
         t_start,
-        t_end,
-        function(t){fX(t)*A}
+        t_end
       )
       Mod=GeneralModel(t=t,A=Af,ivList=C0,inputFluxes=inputFluxes,solver,pass)
      return(Mod)
