@@ -4,6 +4,7 @@ TwopParallelModel<-structure(
     function #Implementation of a two pool model with parallel structure
     ### This function creates a model for two independent (parallel) pools. 
     ### It is a wrapper for the more general function \code{\link{ParallelModel}} that can handle an arbitrary number of pools.
+    ##references<< Sierra, C.A., M. Mueller, S.E. Trumbore. 2012. Models of soil organic matter decomposition: the SoilR package version 1.0. Geoscientific Model Development 5, 1045-1060.
      (t,			##<< A vector containing the points in time where the solution is sought.
      ks,	##<< A vector of length 2 containing the decomposition rates for the 2 pools. 
      C0,	##<< A vector of length 2 containing the initial amount of carbon for the 2 pools.
@@ -20,18 +21,16 @@ TwopParallelModel<-structure(
       if(length(C0)!=2) stop("the vector with initial conditions must be of length = 2")
       if(gam > 1 | gam < 0) stop("The the partitioning coefficient gam is outside the interval [0,1]")
       
-      if(length(In)==1) inputrates=TimeMap.new(
+      if(length(In)==1) inputrates=BoundInFlux(
+        function(t){matrix(nrow=2,ncol=1,c(gam*In,(1-gam)*In))},
         t_start,
-        t_stop,
-        function(t){matrix(nrow=2,ncol=1,c(gam*In,(1-gam)*In))}
+        t_stop
       )
       if(class(In)=="data.frame"){
          x=In[,1]  
          y=In[,2]  
          inputrate=function(t0){as.numeric(spline(x,y,xout=t0)[2])}
-         inputrates=TimeMap.new(
-            min(x),
-            max(x),
+         inputrates=BoundInFlux(
             function(t){
                 matrix(nrow=2,ncol=1,
                     c(
@@ -39,7 +38,9 @@ TwopParallelModel<-structure(
                         (1-gam)*inputrate(t)
                     )
                 )
-            }
+            },
+            min(x),
+            max(x)
          )   
         }
       
@@ -53,7 +54,7 @@ TwopParallelModel<-structure(
       coeffs=TimeMap.new(
         t_start,
         t_stop,
-        function(times){fX(t)*(-1*abs(ks))}
+        function(t){fX(t)*(-1*abs(ks))}
       )
       res=ParallelModel(t,coeffs,startvalues=C0,inputrates,solver,pass=pass)
       ### A Model Object that can be further queried 
