@@ -1,7 +1,7 @@
 #
 # vim:set ff=unix expandtab ts=2 sw=2:
 fW.Daycent2<-structure(
-  function ##Effects of moisture on decomposition rates according to the DAYCENT model
+  function # Effects of moisture on decomposition rates according to the DAYCENT model
     ### Calculates the effects of volumetric water content on decomposition rates according to the Daycent/Century models.
     ##references<<  Del Grosso, S. J., W. J. Parton, A. R. Mosier, E. A. Holland, E. Pendall, D. S. Schimel, and D. S. Ojima (2005), 
     ##Modeling soil CO2 emissions from ecosystems, Biogeochemistry, 73(1), 71-91.
