@@ -1,3 +1,5 @@
+#
+# vim:set ff=unix expandtab ts=2 sw=2:
 fW.Standcarb<-structure(
   function #Effects of moisture on decomposition rates according to the StandCarb model
     ### Calculates the effects of moisture on decomposition rates according to the StandCarb model.
@@ -31,10 +33,13 @@ fW.Standcarb<-structure(
       DeadBranch=fW.Standcarb(MC,MoistMax=200)
       DeadWood=fW.Standcarb(MC,MoistMax=150)
       StableSoil=fW.Standcarb(MC,MoistMin=15,MoistMax=100)
-      plot(MC,DeadFoliage$MoistDecayIndex,type="l",xlab="Moisture Content (%)",ylab="f(W) (unitless)",main="Effects of moisture on decomposition rates according to the StandCarb model")
+      plot(MC,DeadFoliage$MoistDecayIndex,type="l",xlab="Moisture Content (%)",
+           ylab="f(W) (unitless)",
+           main="Effects of moisture on decomposition rates according to the StandCarb model")
       lines(MC,DeadBranch$MoistDecayIndex,col=4)
       lines(MC,DeadWood$MoistDecayIndex,col=3)
       lines(MC,StableSoil$MoistDecayIndex,col=2)
-      legend("topright",c("Dead Foliage","Dead Branch","Dead Wood","Stable Soil"),lty=c(1,1,1),col=c(1,4,3,2),bty="n")
+      legend("topright",c("Dead Foliage","Dead Branch","Dead Wood","Stable Soil"),
+             lty=c(1,1,1),col=c(1,4,3,2),bty="n")
     }
 )
