@@ -23,7 +23,7 @@ plotCPool<-structure(
     Ex=ThreepFeedbackModel14(
       t=years,ks=c(k1=1/2.8, k2=1/35, k3=1/100),C0=c(200,5000,500),
       F0=c(0,0,0), In=LitterInput, a21=0.1,a12=0.01,a32=0.005,a23=0.001,
-      FcAtm=C14Atm_NH
+      inputFc=C14Atm_NH
     )
     Ct=getC(Ex)
     Rt=getReleaseFlux(Ex)
