@@ -3,7 +3,8 @@
 source("prolog.R")
 alltests <- defineTestSuite(
    name="allTests",
-   dirs=".",
+   #dirs=c("."),
+   dirs=c(".","protected","automatic"),
    testFileRegexp = "^runit.+\\.[rR]",
    testFuncRegexp = "^test.+",
    rngKind = "Marsaglia-Multicarry",
